/*
 * @Author: fxs bjnsfxs@163.com
 * @Date: 2024-08-20 17:15:49
 * @LastEditors: fxs bjnsfxs@163.com
 * @LastEditTime: 2024-10-16 10:54:55
 * @Description:
 *
 */
import type { ResponseInfo } from '@/types/res'
import type { TablePaginationSetting } from '@/types/table'

import { initLoadResource } from '@/utils/resource'
import { reactive } from 'vue'

import axiosInstance from '../utils/axios/axiosInstance'

// 资源的加载路径
const resourceInfo: Record<string, string> = {
  defaultHead: `/img/default/defaultHead.png`
}

// 使用blob的资源路径信息
const blobUrlInfo = reactive<Record<string, string>>({})

// 初始化资源
initLoadResource(resourceInfo).then((data) => {
  Object.assign(blobUrlInfo, data)
})

export function useTable(tableData: Array<any>, paginationSetting: TablePaginationSetting) {
  /**
   * @description: 设置默认头像
   * @param {Array} data 请求回来的数据表格
   * @return {Array<any>} 返回处理后的数据
   */
  const setDefaultHead = (data: Array<any>): Array<any> => {
    if (data) {
      data.map(async (item: any) => {
        if (!item.head) item.head = blobUrlInfo.defaultHead
      })
    }
    return data
  }

  /**
   * @description: 获取表格数据
   * @param {string} url 请求地址
   * @param {any} option 请求参数
   * @param {boolean} isPagination 是否开启分页
   */
  const getTableData = (url: string, option: any, isPagination: boolean = false) => {
    return new Promise(async (resolve, reject) => {
      try {
        await axiosInstance.post(url, option).then(async (result) => {
          let info = JSON.parse(JSON.stringify(result)) as ResponseInfo
          let data = info.data
          console.log('执行了')

          // 没有数据则直接置为空
          if (!data) {
            tableData.length = 0
            paginationSetting.total = 0
          } else {
            paginationSetting.total = info.count ?? data.length
            data = setDefaultHead(data)
            // 如果开启了分页，那么默认这个tableData是一个二维数组，每个位置对应当页的一个数据数组
            // 没开启则是一个一维数组，直接赋值
            if (isPagination) tableData[paginationSetting.currentPage] = data
            else tableData.splice(0, tableData.length, ...data)
          }

          resolve(true)
        })
      } catch (err) {
        console.log(err)
        reject(err)
        throw new Error('网络请求错误')
      }
    })
  }

  return {
    getTableData
  }
}
