/**
 * 从localstorage获取数据
 * @param {string} name localstorage的key
 * @param {string} prop 属性名，不传就返回整个对象
 */
const getLocalInfo = (name: string, prop?: string): string | string[] => {
  let info = localStorage.getItem(name)
  let result = ''
  if (info) {
    let jsonInfo = JSON.parse(info)

    if (prop) result = jsonInfo[prop]
    else result = jsonInfo
  }

  return result
}

/**
 * 保存到本地
 * @param {string} name localstorage的key
 * @param {any} value 值
 * @param {string} prop 属性名
 */
const saveLocalInfo = (name: string, value: any, prop?: string) => {
  let info = localStorage.getItem(name)
  if (info) {
    let jsonInfo = JSON.parse(info)
    if (prop) jsonInfo[prop] = value
    localStorage.setItem(name, JSON.stringify(jsonInfo))
  } else {
    localStorage.setItem(name, JSON.stringify(value))
  }
}

/**
 * 设置登陆状态
 * @param {boolean} state 登录状态
 */
const setLoginState = (state: boolean) => {
  localStorage.setItem('loginState', JSON.stringify(state))
}

/**
 * 获取当前登录状态
 */
const getLoginState = (): boolean => {
  return JSON.parse(localStorage.getItem('loginState') as string) as boolean
}

export { getLocalInfo, saveLocalInfo, setLoginState, getLoginState }
